@@ -1,28 +1,15 @@
-import os,sys,unicodedata,hashlib,json,logging
+
 from flask_cors import CORS
 from abstract_utilities import make_list,get_media_types,get_logFile
 from multiprocessing import Process
-
-from flask import (
-    Blueprint,
-    request,
-    jsonify,
-    send_file,
-    current_app,
-    Flask,
-    redirect,
-    send_from_directory,
-    abort,
-    Flask,
-    has_request_context
-    
-)
+from flask import *
 from abstract_queries import USER_IP_MGR
 from .file_utils import *
 from .request_utils import *
 from .network_utils import *
-
 from werkzeug.utils import secure_filename
+import os,sys,unicodedata,hashlib,json,logging
+logger = get_logFile('abstract_flask')
 def get_from_kwargs(keys,**kwargs):
     output_js = {}
     for key in keys:
@@ -30,7 +17,7 @@ def get_from_kwargs(keys,**kwargs):
             output_js[key]= kwargs.get(key)
             del kwargs[key]
     return output_js,kwargs
-def get_name(name,abs_path=None):
+def get_name(name=None,abs_path=None):
     if os.path.isfile(name):
         basename = os.path.basename(name)
         name = os.path.splitext(basename)[0]
@@ -40,9 +27,9 @@ def jsonify_it(obj):
     if isinstance(obj,dict):
         status_code = obj.get("status_code")
         return jsonify(obj),status_code
-def get_bp(name,abs_path=None, **bp_kwargs):
+def get_bp(name=None,abs_path=None, **bp_kwargs):
     # if they passed a filename, strip it down to the module name
-    name,abs_path = get_name(name,abs_path=None)
+    name,abs_path = get_name(name=name,abs_path=abs_path)
     bp_name = f"{name}_bp"
     logger  = get_logFile(bp_name)
     logger.info(f"Python path: {sys.path!r}")
